#!/bin/bash


cd $( dirname $0 )

##--------------------------------------------------------------------------------
## Set flags & defaults
##--------------------------------------------------------------------------------

TRUST_MAIN_DIR=$PWD
TRUST_FLAG_HELP='false'
TRUST_FLAG_DEBUG='false'; TRUST_FLAG_DEV='false' ; TRUST_FLAG_PROD='false'

# Revision number of the tool
rev=$( svn info | awk '/Last Changed Rev/ {print $NF}' )


##--------------------------------------------------------------------------------
## Get short or long arguments from command line
##--------------------------------------------------------------------------------

while getopts a:b:de:f:j:hm:n:r:t:pu:v:w: arg; do

    case $arg in
	a)  TRUST_IO_FORC_TAR=$OPTARG;; b)    TRUST_SVN_BRANCH=$OPTARG;;
	d) TRUST_FLAG_DEBUG='true'   ;; e)  TRUST_TEST_MAILING=$OPTARG;;
	f) TRUST_IO_FORC_PATH=$OPTARG;; j) TRUST_COMPILE_NPROC=$OPTARG;;
	h)  TRUST_FLAG_HELP='true'   ;; m)     TRUST_MAIN_HPCC=$OPTARG;;
	n)      TRUST_CFG_NEW=$OPTARG;; r)       TRUST_CFG_REF=$OPTARG;;
	t)  TRUST_JOB_TIMEOUT=$OPTARG;; p)   TRUST_FLAG_PROD='true'   ;;
	u)    TRUST_MAIN_USER=$OPTARG;; v)       TRUST_SVN_REV=$OPTARG;;
	w)     TRUST_DIR_WORK=$OPTARG;;
	:) echo 'Arg. needed for '$OPTARG && TRUST_FLAG_HELP='true'   ;;
	*)  TRUST_FLAG_HELP='true'                                    ;;
    esac

done


##--------------------------------------------------------------------------------
## Initialization (user & HPC environment)
##--------------------------------------------------------------------------------

if [[ ! -e cfg/${TRUST_MAIN_USER}.cfg || ! -e cfg/${TRUST_MAIN_HPCC}.cfg \
      || ${TRUST_FLAG_HELP} == 'true'                                      ]]; then
    cat ./inc/trusting_help.txt

    ## Color this section to part with help
    printf "\033[0;33m"

    if [ ${TRUST_FLAG_HELP} == 'false' ]; then
	printf "                                                           \
	    \nAt least 1 cfg file (arch or user) is missing or misspelled: \
	    '%s.cfg' or '%s.cfg'\n"                                        \
	    ${TRUST_MAIN_USER} ${TRUST_MAIN_HPCC}
    fi

    echo -e "\nContent of './cfg' folder:"
    find ./cfg -name *.cfg | cut -d/ -f3 \
	| xargs -n 3 printf "%-20s\t%-20s\t%-20s\n"
    printf "\033[0m\n"

    exit 1
else
    ## Verbose output on debug mode
    [ ${TRUST_FLAG_DEBUG} == 'true' ] && set -vx

    . ./inc/trusting.env
    . ./inc/trusting_func.sh

fi


##--------------------------------------------------------------------------------
## Trusting workflow
##--------------------------------------------------------------------------------

## Test summary
##-------------

echo
if [ -t 0 ]; then cat ./inc/banner.txt; else cat ./inc/banner.html; fi
echo
echo '****************************************************************************************************'
echo '*                                                                                                  *'
echo '*                           NEMO Trusting (Continuous Integration Tool)                            *'
echo "*                                             ver.$rev                                             *"
echo '*                                                                                                  *'
echo '****************************************************************************************************'
echo
printf "\t§ Testing configuration\t\t%s on branch %s\n" \ ${TRUST_CFG_REF} ${TRUST_SVN_BRANCH}
printf "\t§ (Super)Computer\t\t%s\n" 		          ${TRUST_MAIN_HPCC}
printf "\t§ User installation\t\t%s\n\n" 	          ${TRUST_MAIN_USER}
echo
if [ ${TRUST_TEST_BENCHMARK} ]; then
printf "\t§ Benchmark folder\n\t\t\t%s\n"      	          ${TRUST_TEST_BENCHMARK}
fi


## Testing directory
##------------------

step 'Testing directory'
init


## Local working copy
##-------------------

step 'Local working copy'

echo "${TRUST_SVN_ACTION} on ${TRUST_SVN_NEMOGCM}:"
get_nemo_rev


## Environment
##------------

step 'Environment'
get_soft_rel


## Compilation(s)
##---------------

step 'Compilation(s)'

printf "XIOS? "
compile_xios

printf "\nNEMO ${TRUST_CFG_NEW} cfg. from ${TRUST_CFG_REF}? "
compile_nemo


## Inputs
##-------

step 'Inputs'

get_inputs

printf "\nCompare with benchmark? "
diff_inputs


## Job
##----

step 'Job'

printf "Submit? "
job_submit

echo 'Pending...'
job_pending

echo 'Finished!'

printf "State? "
job_state

printf "Perfs?"
job_perfs


## Output(s)
##----------

step 'Ouput(s)'

echo 'Compare with benchmark:'

printf "Plain text files? "
diff_results

printf "Restart files? "
diff_restarts


## End, at least nothing major has changed ;-)
##--------------------------------------------

get_out 0
